
* Please create a directory for storing the data in a subdirectory: \Data and a directory for results: \Results

local Directory = "C:\"  

* Table 1a: Sample distribution US mutual fund ownership by country within emerging and developed markets 

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear
collapse (count) ret, by(country emerging)
sort emerging country
rename ret no_of_observations
outsheet using "`Directory'\Results\Table 1a.csv",comma replace

* Table 1b: Descriptive statistics of variables 

set more off
use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear
gen lnew_information1002 = lnew_information100*1000
gen lattention1002 = lattention100*1000
gen lnewscoverage1002 = lnewscoverage1003*1000
estpost sum trmf_fus trmf_fnus lnewscoverage1002 lnew_information1002 lattention1002 ias bign mv bm dy roe ret std_y adr age ch, detail 
esttab using "`Directory'\Results\Table 1b.csv", cells("mean(fmt(2)) sd(fmt(2)) p50(fmt(2)) p10(fmt(2)) p90(fmt(2))") nomtitle nonumber label replace

* Table 1c: Mean values of variables by country 

set more off
use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear
gen lnew_information = ltotal_press_release1003*1000
gen lnew_information2 = lnewnews3*1000
gen lattention = ltotal_news_flash1003*1000
gen lattention2 = loldnews3*1000
gen lnewscoverage1002 = lnewscoverage1003*1000
collapse (mean) trmf_fus trmf_fnus lnewscoverage1002 lnew_information lnew_information2 lattention lattention2, by(country emerging)
sort emerging country
drop if country == "United States "
format trmf_fus trmf_fnus lnewscoverage1002 lnew_information lnew_information2 lattention lattention2 %12.2f
outsheet using "`Directory'\Results\Table 1c.csv",comma replace

* Table 2: News coverage and US mutual fund ownership (all news) 

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear

global 	control ias bign mv bm dy roe ret std_y adr age ch

set more off

xi: reg trmf_fus lnewscoverage1003 if fccode != "US", robust cluster(dscode) 
outreg2 lnewscoverage1003 using "`Directory'\Results\Table 2.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership no controls") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) replace
xi: reg trmf_fus lnewscoverage1003 $control if fccode != "US" & emerging == 0, robust cluster(dscode) 
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 2.xls",  label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fus lnewscoverage1003 $control i.year if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 2.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append
xi: areg trmf_fus lnewscoverage1003 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 2.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fus lnewscoverage1003 $control i.year if fccode != "US" & emerging == 0, robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 2.xls",  label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with firm & year FE (developed markets)") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append
xi: areg trmf_fus lnewscoverage1003 $control i.year if fccode != "US" & emerging == 1, robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 2.xls",  label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with firm & year FE (emerging markets)") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* Table 3: Non-US mutual fund ownership, domestic mutual fund ownership and US mutual fund ownership 

global 	control ias bign mv bm dy roe ret std_y adr age ch

set more off

xi: areg trmf_fnus lnewscoverage1003 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 3.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("Non-US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) replace

xi: areg trmf_d lnewscoverage1003 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 3.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("Domestic mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* Table 4 Fund characterisitics 


global 	control ias bign mv bm dy roe ret std_y adr age ch

set more off

replace trmf_fuslt = trmf_fuslt*100
replace trmf_fusst = trmf_fusst*100
replace trmf_fusb = trmf_fusb*100
replace trmf_fusnb = trmf_fusnb*100

xi: areg trmf_fuslt lnewscoverage1003 $control i.year i.countyyear i.industryyear  if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 4.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US LT mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) replace

xi: areg trmf_fusst lnewscoverage1003 $control i.year i.countyyear i.industryyear  if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 4.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US ST mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fusb lnewscoverage1003 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 4.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US Block mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fusnb lnewscoverage1003 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 4.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US non-Block mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* Table 5 Type of News 

set more off

gen trmf_fus_d = trmf_fus + trmf_d

replace trmf_fuslt = trmf_fuslt*100
replace trmf_fusst = trmf_fusst*100
replace trmf_fusb = trmf_fusb*100
replace trmf_fusnb = trmf_fusnb*100
sort stockid year
tsset stockid year
winsor lnewnews3, gen(lnewnews4) p(0.005)
winsor loldnews3, gen(loldnews4) p(0.005)
by stockid: gen lvolumescaled= volumescaled[_n-1]
gen lattention2_fr = loldnews4/(lnewnews4+loldnews4) 
gen lattention2_fr2 = loldnews4/(lnewnews4)  
gen lattention3_fr = ltotal_media_coverage1003/ltotal_press_release1003
gen lattention4_fr = ltotal_media_coverage1003/lnewscoverage1003
gen lattention5 = lvolumescaled
set more off
gen lvolumescaledlcover = lattention5*lnewscoverage1003 

global control ias bign mv bm dy roe ret std_y adr age ch

tsset stockid year
winsor total_press_release100, gen(total_press_release1004) p(0.05)
replace total_press_release1004 = total_press_release1004/1000 
by stockid: gen ltotal_press_release1004  = total_press_release1004[_n-1]

replace ltotal_press_release1004 = . if ltotal_press_release1003 == .

gen linformation1 = ltotal_press_release1004 
gen linformation2 = lnewnews3

gen lattention1 = lattention100
gen lattention2 = loldnews4

global 	control ias bign mv bm dy roe ret std_y adr age ch
set more off
 
 * Table 5: Information (x2 columns) & Attention (x2 columns)
 * information definition: news originated by press releases + new news (novelty score = 100) 
 * Attention definition: news flashes + old news (novelty score < 100)
  
xi: areg trmf_fus linformation1 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)

outreg2 linformation1 $control i.year using "`Directory'\Results\Table 5.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm FE, information: press releases only ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) replace

xi: areg trmf_fus linformation2 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 linformation2 $control i.year using "`Directory'\Results\Table 5.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm FE, information: news with novelty score of 100") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fus lattention1 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lattention1 $control i.year using "`Directory'\Results\Table 5.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm FE, attentnion: news flash only ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fus lattention2 $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lattention2 $control i.year using "`Directory'\Results\Table 5.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm FE, attention: old news, novelty score < 100") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append
 
* Table 6: Good news vs Bad news across 3 definitions:50/50, 25/75, 10/90
  
* All US mutual funds

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear
 
gen lgoodnews = lgoodnews50w
gen lbadnews = lbadnews50w
xi: areg trmf_fus lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm FE, Good news: 50 and Bad news 50") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) replace

replace lgoodnews = lgoodnews75w
replace lbadnews = lbadnews25w
xi: areg trmf_fus lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm FE, Good news: 75 and Bad news 25") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews90w
replace lbadnews = lbadnews10w
xi: areg trmf_fus lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm FE, Good news: 90 and Bad news 10") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* LT/ST mutual funds
 
replace lgoodnews = lgoodnews50w
replace lbadnews = lbadnews50w
xi: areg trmf_fuslt lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US LT mutual fund ownership with controls, firm FE, Good news: 50 and Bad news 50") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews75w
replace lbadnews = lbadnews25w
xi: areg trmf_fuslt lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US LT mutual fund ownership with controls, firm FE, Good news: 75 and Bad news 25") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews90w
replace lbadnews = lbadnews10w
xi: areg trmf_fuslt lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US LT mutual fund ownership with controls, firm FE, Good news: 90 and Bad news 10") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append
 
replace lgoodnews = lgoodnews50w
replace lbadnews = lbadnews50w
xi: areg trmf_fusst lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US ST mutual fund ownership with controls, firm FE, Good news: 50 and Bad news 50") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews75w
replace lbadnews = lbadnews25w
xi: areg trmf_fusst lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US ST mutual fund ownership with controls, firm FE, Good news: 75 and Bad news 25") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews90w
replace lbadnews = lbadnews10w
xi: areg trmf_fusst lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US ST mutual fund ownership with controls, firm FE, Good news: 90 and Bad news 10") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* Block / Non-Block mutual funds
 
replace lgoodnews = lgoodnews50w
replace lbadnews = lbadnews50w
xi: areg trmf_fusb lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US Block mutual fund ownership with controls, firm FE, Good news: 50 and Bad news 50") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews75w
replace lbadnews = lbadnews25w
xi: areg trmf_fusb lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US Block mutual fund ownership with controls, firm FE, Good news: 75 and Bad news 25") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews90w
replace lbadnews = lbadnews10w
xi: areg trmf_fusb lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US Block mutual fund ownership with controls, firm FE, Good news: 90 and Bad news 10") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append
 
replace lgoodnews = lgoodnews50w
replace lbadnews = lbadnews50w
xi: areg trmf_fusnb lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US Non-Block mutual fund ownership with controls, firm FE, Good news: 50 and Bad news 50") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews75w
replace lbadnews = lbadnews25w
xi: areg trmf_fusnb lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US Non-Block mutual fund ownership with controls, firm FE, Good news: 75 and Bad news 25") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

replace lgoodnews = lgoodnews90w
replace lbadnews = lbadnews10w
xi: areg trmf_fusnb lgoodnews lbadnews $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lgoodnews lbadnews $control i.year using "`Directory'\Results\Table 6.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US Non-Block mutual fund ownership with controls, firm FE, Good news: 90 and Bad news 10") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* Table 7  

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear
	
foreach cf in bign highana ias adr {		

gen lnewscoverage1003_cf = lnewscoverage1003*`cf'
label variable lnewscoverage1003_cf "lnewscoverage1003 x country factor"

xi: areg trmf_fus lnewscoverage1003 `cf' lnewscoverage1003_cf $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 `cf' lnewscoverage1003_cf $control using "`Directory'\Results\Table 7.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership - `cf'") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append
drop lnewscoverage1003_cf 
}

* Table 8  

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear

foreach cf in disreq secreg english {		

gen lnewscoverage1003_cf = lnewscoverage1003*`cf'
label variable lnewscoverage1003_cf "lnewscoverage1003 x country factor"

xi: areg trmf_fus lnewscoverage1003 `cf' lnewscoverage1003_cf $control i.year i.countyyear i.industryyear if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 `cf' lnewscoverage1003_cf $control using "`Directory'\Results\Table 8.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership - `cf'") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append
drop lnewscoverage1003_cf 
}

* Table 9 

use "`Directory'\Data\FinalData (Tables 9) - First Stage Regression Result.dta", clear

gen abs_beta_diff = abs(fmr_b - USmr_b)
gen abs_news_beta = abs(news_b)
gen ln_abs_beta_diff = ln(abs_beta_diff)
gen ln_abs_news_beta = ln(abs_news_beta)

winsor abs_beta_diff, gen(abs_beta_diffw) p(0.01)
winsor abs_news_beta, gen(abs_news_betaw) p(0.01)
reg ln_abs_beta_diff ln_abs_news_beta, robust cluster(isin)

outreg2 using "`Directory'\Results\Table 9.xls",  label(insert) bdec(3) aster tstat tdec(2) cttop("ALL mutual fund ownership -  log absolute beta differential weekly returns") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* Table 10 Robustness Check 

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear

xi: areg trmf_fus lnewscoverage1003 $control i.year i.countyyear i.industryyear if fccode != "US" & adr == 0, robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 10.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) replace

xi: areg trmf_fus lnewscoverageFULL3 $control i.year i.countyyear i.industryyear if fccode != "US" , robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverageFULL3 $control using "`Directory'\Results\Table 10.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fus ltrnews3 $control i.year i.countyyear i.industryyear if fccode != "US" , robust cluster(dscode) absorb(dscode)
outreg2 ltrnews3 $control using "`Directory'\Results\Table 10.xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fus lnewscoverage1003 $control i.year i.countyyear i.industryyear if fccode != "US" & year < 2008, robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage1003 $control using "`Directory'\Results\Table 10.xls",  label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership (non-GFC)") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

xi: areg trmf_fus lnewscoverage_excl_ea3 $control i.year if fccode != "US", robust cluster(dscode) absorb(dscode)
outreg2 lnewscoverage_excl_ea3 $control using "`Directory'\Results\Table 10.xls",  label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership (Exclude Earnings Annoucements)") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

* Table 11: GMM

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear

xi: ivreg2 trmf_fus ias bign mv bm dy roe ret std_y adr age ch i.year i.industryid  (lnewscoverage1003 = other_lnewscoverage1003 english ln_population) if fccode != "US", savefirst first robust cluster(dscode) gmm2s endog(lnewscoverage1003)

outreg2 using "`Directory'\Results\Table 11 (GMM).xls", label(insert) bdec(3) aster tstat tdec(2) cttop("GMM") nonotes rdec(4) addstat(J statistics, e(j), p-value of Hansen J statistic, e(jp)) replace

xi: ivreg2 trmf_fus ias bign mv bm dy roe ret std_y adr age ch i.year i.industryid (lnewscoverage1003 = other_lnewscoverage1003 english ln_population) if fccode != "US" & emerging == 0, savefirst first robust cluster(dscode) gmm2s endog(lnewscoverage1003)

outreg2 using "`Directory'\Results\Table 11 (GMM).xls", label(insert) bdec(3) aster tstat tdec(2) cttop("GMM") nonotes rdec(4) addstat(J statistics, e(j), p-value of Hansen J statistic, e(jp)) append

xi: ivreg2 trmf_fus ias bign mv bm dy roe ret std_y adr age ch i.year i.industryid (lnewscoverage1003 = other_lnewscoverage1003 english ln_population) if fccode != "US" & emerging == 1, savefirst first robust cluster(dscode) gmm2s endog(lnewscoverage1003)

outreg2 using "`Directory'\Results\Table 11 (GMM).xls", label(insert) bdec(3) aster tstat tdec(2) cttop("GMM") nonotes rdec(4) addstat(J statistics, e(j), p-value of Hansen J statistic, e(jp)) append

* Table 12: PSM

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear

gen newcovered = 1 if lnewscoverage1003 > 0 & lnewscoverage1003 != .
replace newcovered = 0 if lnewscoverage1003 == 0 & lnewscoverage1003 != .

psmatch2 newcovered bign msci mv bm dy roe ret std_y adr age ch english ln_population other_lnewscoverage1003 i.year i.industryid i.countyyear i.industryyear , kernel k(biweight) bw(0.15) logit common outcome(trmf_fus) 
outreg2 using "`Directory'\\Results\Table 12 (PSM).xls", label(insert) bdec(3) aster tstat tdec(3) cttop("US mutual fund ownership with controls, industry & year FE ") nonotes  adjr2 rdec(3) replace

psmatch2 newcovered bign msci mv bm dy roe ret std_y adr age ch english ln_population other_lnewscoverage1003 i.year i.industryid i.countyyear i.industryyear if emerging == 0, kernel k(biweight) bw(0.15) logit common outcome(trmf_fus) 
outreg2 using "`Directory'\\Results\Table 12 (PSM).xls", label(insert) bdec(3) aster tstat tdec(3) cttop("US mutual fund ownership with controls, industry & year FE ") nonotes  adjr2 rdec(3) append

psmatch2 newcovered bign msci mv bm dy roe ret std_y adr age ch english ln_population other_lnewscoverage1003 i.year i.industryid i.countyyear i.industryyear if emerging == 1, kernel k(biweight) bw(0.15) logit common outcome(trmf_fus) 
outreg2 using "`Directory'\\Results\Table 12 (PSM).xls", label(insert) bdec(3) aster tstat tdec(3) cttop("US mutual fund ownership with controls, industry & year FE ") nonotes  adjr2 rdec(3) append

* Table 13: Heckman

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear

gen newcovered = 1 if lnewscoverage1003 > 0 & lnewscoverage1003 != .
replace newcovered = 0 if lnewscoverage1003 == 0 & lnewscoverage1003 != .

probit newcovered bign msci mv bm dy roe ret std_y adr age ch ln_population other_lnewscoverage1003 i.year i.industryid i.industryyear i.countyyear
predict probitxb, xb
gen pdfprobit = normalden(probitxb)
gen cdfprobit = normal(probitxb)
gen imr = pdfprobit/cdfprobit /* gets the inverse mills ratio*/

save 
set more off
xi: reg trmf_fus lnewscoverage1003  $control imr i.year i.industryid i.industryyear i.countyyear if fccode != "US", robust cluster(industryid)
outreg2 lnewscoverage1003  $control imr using "`Directory'\Results\Table 13 (Heckman).xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) replace

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear
gen newcovered = 1 if lnewscoverage1003 > 0 & lnewscoverage1003 != .
replace newcovered = 0 if lnewscoverage1003 == 0 & lnewscoverage1003 != .
keep if fccode != "US" & emerging == 0
probit newcovered bign msci mv bm dy roe ret std_y adr age ch ln_population other_lnewscoverage1003 i.year i.industryid i.countryid
predict probitxb, xb
gen pdfprobit = normalden(probitxb)
gen cdfprobit = normal(probitxb)
gen imr = pdfprobit/cdfprobit /* gets the inverse mills ratio*/

set more off
xi: reg trmf_fus lnewscoverage1003 $control imr  i.year i.industryid i.industryyear i.countyyear if fccode != "US" & emerging == 0 , robust cluster(industryid)
outreg2 lnewscoverageFULL3 $control imr using "`Directory'\Results\Table 13 (Heckman).xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append

use "`Directory'\Data\FinalData (Tables 1-8, 10-13).dta", clear
gen newcovered = 1 if lnewscoverage1003 > 0 & lnewscoverage1003 != .
replace newcovered = 0 if lnewscoverage1003 == 0 & lnewscoverage1003 != .
keep if fccode != "US" & emerging == 1
probit newcovered bign msci mv bm dy roe ret std_y adr age ch ln_population other_lnewscoverage1003 i.year i.industryid i.industryyear i.countyyear
predict probitxb, xb
gen pdfprobit = normalden(probitxb)
gen cdfprobit = normal(probitxb)
gen imr = pdfprobit/cdfprobit /* gets the inverse mills ratio*/

set more off
xi: reg trmf_fus lnewscoverage1003 $control imr i.year i.industryid i.industryyear i.countyyear if fccode != "US" & emerging == 1, robust cluster(industryid)
outreg2 lnewscoverageFULL3 $control imr using "`Directory'\Results\Table 13 (Heckman).xls", label(insert) bdec(3) aster tstat tdec(2) cttop("US mutual fund ownership with controls, firm & year FE ") nonotes  adjr2 rdec(4) addstat(Number of firms, e(N_clust)) append


